import { Fragment, useCallback, useState } from 'react';
import { PresetManager } from '@bryntum/gantt';
import GanttView from './GanttView';

const BryntumContainer =  props => {
    const {
        startDate = new Date(),
        viewPreset  = 'weekAndDayLetter',
        ganttRef
    } = props;

	const [selectedProject, setSelectedProject] = useState(null);
	const onSelectProject = useCallback((data) => {
    	setSelectedProject(()=>data);
	},[]);
	
	const requiredPresetIds = {
        secondAndMinute   : 1, //minutes and seconds
        minuteAndHour     : 1, //hours and minutes
        hourAndDay        : 1, //days and hours
        //dayAndWeek        : 1, //weeks and days 
        //dayAndMonth       : 1, //months and days
        dayNightShift     : 1, 
        weekAndDay        : 1, //just like dayAndWeek but with different formatting
        weekAndMonth      : 1, //months and weeks
        weekAndDayLetter  : 1, //weeks and day
        weekDateAndMonth  : 1, //months and weeks (weeks shown by first day only)
        weekNumberAndYear : 1,
        monthAndYear      : 1, //years and months
        year              : 1, //years and quarters
        manyYears         : 1  //5-years and years
    };
	// The set of available Presets is what provides the zoom levels.
    const presets = PresetManager.records.filter(p => requiredPresetIds[p.id])
	
	const onZoomClick = (value) => {
        if(value==='zoomIn')
            ganttRef?.current?.instance?.zoomIn();
        else if(value==='zoomOut')
			ganttRef?.current?.instance?.zoomOut();
        else //zoomToFit
            ganttRef?.current?.instance?.zoomToFit();
    };

	return (<Fragment>
        <GanttView
            ganttRef = {ganttRef}
            startDate ={startDate}
            viewPreset = {viewPreset} 
			presets = {presets}
			selectedProject = {selectedProject}
			onZoomClick = {onZoomClick}			
            onSelectProject = {onSelectProject}
        />
	</Fragment>);
}
export default BryntumContainer;
