import React, { useCallback, useEffect, useState } from 'react';
import { BryntumGantt } from '@bryntum/gantt-react';
import { AjaxStore, DateHelper, DomHelper, PresetManager, StringHelper, TaskTooltip, Toast} from '@bryntum/gantt';
import taskData from './taskData.json';

const GanttView =  props => {
    const {
        startDate = new Date(),
        viewPreset  = 'weekAndDayLetter',
		presets,
        ganttRef,
		selectedProject,
		onZoomClick,
        onSelectProject 
    } = props;

	const [filterProject, setFilterProject] = useState(false);
	const filterResources = ({checked}) => {
        setFilterProject(checked);
    };

    /*const [filterResourcesLabel, setFilterResourcesLabel] = useState('Project : None Selected');
    useEffect(()=>{
        console.log(filterProject,selectedProject);
        if(filterProject && selectedProject)
            setFilterResourcesLabel('Project : '+selectedProject?.name);
        else
            setFilterResourcesLabel('Project : None Selected');
        
    },[selectedProject,filterProject]);*/

	const [ganttConfig, setGanttConfig] = useState({
        startDate           : startDate,
        viewPreset          : viewPreset,
        presets             : presets,
        //visibleZoomFactor   : 10,
        barMargin           : 2,
        rowHeight           : 20,
        timeRangesFeature   : {
            showCurrentTimeLine : true
        },
        // The following features are enabled by default:
        features : {
            cellEdit      : true, //isGanttEditable
        },
        columns: [
            { 
                type: 'name', 
                text : 'Project',  
                field: 'name', 
                width: 250, 
                renderer: ({record}) => {
                    return record.isLeaf ? <span>{record.name}</span> : <b>{record.name}</b>
                }
            }
        ],
        // Custom task content, display task name on child tasks
        taskRenderer({ taskRecord }) {
            if (taskRecord.isLeaf && !taskRecord.isMilestone) {
                return StringHelper.encodeHtml(taskRecord.name);
            }
        },
        listeners : {
            cellClick: ({record} ) =>onSelectProject(record)
        },
		tbar : [
            {
                type     : 'checkbox',
                color    : 'b-blue',
                text     : 'Project : '+(selectedProject?selectedProject.name:'None Selected'),
                style    : 'margin-right: .5em',
                onChange : filterResources
            },
            '->',
            {
                type  : 'buttonGroup',
                toggleGroup : true,
                items : [
                    {
                        ref      : 'zoomInButton',
                        icon     : 'b-fa b-fa-search-plus',
                        tooltip  : 'Zoom In',
                        onAction : () => onZoomClick('zoomIn')
                    },
                    {
                        ref      : 'zoomOutButton',
                        icon     : 'b-fa b-fa-search-minus',
                        tooltip  : 'Zoom Out',
                        onAction : () => onZoomClick('zoomOut')
                    },
                    {
                        ref      : 'zoomToFitButton',
                        icon     : 'b-fa b-fa-expand',
                        tooltip  : 'Zoom to Fit',
                        onAction : () => onZoomClick('zoomToFit')
                    }
                ]
            },
		],
        project:{
            project:{
                "calendar"     : "general",
                "startDate"    : startDate,
                "hoursPerDay"  : 24,
                "daysPerWeek"  : 5,
                "daysPerMonth" : 20
            },
			tasksData: taskData,
            timeRangesData: [
                {
                    "id"       : 1,
                    "name"     : "Important date",
                    "startDate": startDate,
                    "duration" : 0,
                    "durationUnit" : "d",
                    "cls"      : "b-fa b-fa-diamond"
                }
            ],
            autoLoad : true,
            // The State TrackingManager which the UndoRedo widget in the toolbar uses
            stm : {
                autoRecord : true
            }
        }
    });

 return <BryntumGantt ref={ganttRef} {...ganttConfig} />
};
export default React.memo(GanttView);